#include <k3dsdk/algebra.h>
#include <iostream>

int main()
{
	const k3d::matrix4 a(
		k3d::point4(1, 2, 3, 4),
		k3d::point4(5, 6, 7, 8),
		k3d::point4(9, 10, 11, 12),
		k3d::point4(13, 14, 15, 16));

	const k3d::matrix4 b = k3d::transpose(a);

	std::cout << a[0] << "\n" << a[1] << "\n" << a[2] << "\n" << a[3] << "\n\n";
	std::cout << b[0] << "\n" << b[1] << "\n" << b[2] << "\n" << b[3] << "\n\n";
		
	return 0;
}

